==> 1.0.123+1.tar.gz: lib/components/UikIcon.dart <==
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikIconProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';
import 'package:ui_sdk/utils/pub_sub/local_pub_sub.dart';

// ignore: must_be_immutable
class UikIcon extends UikWidget {
  // ignore: prefer_final_fields
  WidgetType _widgetType;
  UikIconProps _UikIconProps;

  UikIcon(this._widgetType, this._UikIconProps)
      : super(_widgetType, _UikIconProps);

  @override
  _UikIconState createState() => _UikIconState(_UikIconProps);
}

class _UikIconState extends State<UikIcon> {
  UikIconProps _UikIconProps;

  _UikIconState(this._UikIconProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        PubSub pubsub = PubSub();
        await executeUikWidgetAction(_UikIconProps.action);
      },
      child: Container(
        padding: EdgeInsets.all(_UikIconProps.padding),
        decoration: (_UikIconProps.borderWidth != 0.0)
            ? BoxDecoration(
                color: _UikIconProps.backgroundColor,
                borderRadius: (_UikIconProps.borderRadius != 0.0)
                    ? BorderRadius.circular(_UikIconProps.borderRadius)
                    : null,
                border: (_UikIconProps.borderWidth != 0.0)
                    ? Border.all(
                        color: _UikIconProps.borderColor,
                        width: _UikIconProps.borderWidth,
                      )
                    : null,
              )
            : null,
        child: Icon(
          _UikIconProps.iconVal,
          size: _UikIconProps.iconSize,
          color: _UikIconProps.iconColor,
        ),
      ),
    );
  }
}

==> 1.0.128+1.tar.gz: lib/components/UikIcon.dart <==
import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikIconProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

// ignore: must_be_immutable
class UikIcon extends UikWidget {
  // ignore: prefer_final_fields
  WidgetType _widgetType;
  UikIconProps _UikIconProps;

  UikIcon(this._widgetType, this._UikIconProps)
      : super(_widgetType, _UikIconProps);

  @override
  _UikIconState createState() => _UikIconState(_UikIconProps);
}

class _UikIconState extends State<UikIcon> {
  UikIconProps _UikIconProps;

  _UikIconState(this._UikIconProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () async {
        await executeUikWidgetAction(_UikIconProps.action,context);
      },
      child: Container(
        padding: EdgeInsets.all(_UikIconProps.padding),
        decoration: (_UikIconProps.borderWidth != 0.0)
            ? BoxDecoration(
                color: _UikIconProps.backgroundColor,
                borderRadius: (_UikIconProps.borderRadius != 0.0)
                    ? BorderRadius.circular(_UikIconProps.borderRadius)
                    : null,
                border: (_UikIconProps.borderWidth != 0.0)
                    ? Border.all(
                        color: _UikIconProps.borderColor,
                        width: _UikIconProps.borderWidth,
                      )
                    : null,
              )
            : null,
        child: Icon(
          _UikIconProps.iconVal,
          size: _UikIconProps.iconSize,
          color: _UikIconProps.iconColor,
        ),
      ),
    );
  }
}
